@@ -23,6 +23,7 @@
             [com.puppetlabs.utils :as utils]
             [com.puppetlabs.jdbc :as jdbc]
             [clojure.java.jdbc :as sql]
+            [clojure.string :as str]
             [clojure.tools.logging :as log]
             [cheshire.core :as json])
   (:use [clj-time.coerce :only [to-timestamp]]
@@ -41,6 +42,15 @@
       (getMetaData)
       (getDatabaseProductName)))
 
+(defn sql-current-connection-database-version
+  "Return the version of the database product currently in use."
+  []
+  (let [db-metadata (.. (sql/find-connection)
+                      (getMetaData))
+        major (.getDatabaseMajorVersion db-metadata)
+        minor (.getDatabaseMinorVersion db-metadata)]
+    [major minor]))
+
 (defn to-jdbc-varchar-array
   "Takes the supplied collection and transforms it into a
   JDBC-appropriate VARCHAR array."
@@ -78,7 +88,9 @@ must be supplied as the value to be matched."
 
 (defmethod sql-array-query-string "PostgreSQL"
   [column]
-  (format "? = ANY(%s)" column))
+  (if (pos? (compare (sql-current-connection-database-version) [8 1]))
+    (format "ARRAY[?::text] <@ %s" column)
+    (format "? = ANY(%s)" column)))
 
 (defmethod sql-array-type-string "HSQL Database Engine"
   [basetype]
@@ -313,7 +325,7 @@ must be supplied as the value to be matched."
   {:pre  [(coll? resource-hashes)
           (every? string? resource-hashes)]
    :post [(set? resource-hashes)]}
-  (let [qmarks     (apply str (interpose "," (repeat (count resource-hashes) "?")))
+  (let [qmarks     (str/join "," (repeat (count resource-hashes) "?"))
         query      (format "SELECT DISTINCT resource FROM resource_params WHERE resource IN (%s)" qmarks)
         sql-params (vec (cons query resource-hashes))]
     (sql/with-query-results result-set
